@@ -34,5 +34,5 @@ def unpack(library, carddir):
     cardpath = pjoin(carddir, "{0}.crd")
 
     for card in lib.retrieve_all():
-        with open(cardpath.format(code), 'w') as cardfile:
+        with open(cardpath.format(card.code), 'w') as cardfile:
             yaml.dump(card.save(), cardfile, default_flow_style=False)
